"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const chalk_1 = __importDefault(require("chalk"));
const config_1 = __importDefault(require("./config/config"));
const Deployer_1 = __importDefault(require("./Deployer"));
const Utils = __importStar(require("./Utils"));
const dc_logging_1 = require("@daocasino/dc-logging");
const log = new dc_logging_1.Logger('DApp');
class DApp extends Deployer_1.default {
    constructor(params) {
        super(params);
        this._params = params;
        this._config = config_1.default;
    }
    async start(options) {
        const startOptions = {
            useDocker: options.docker,
            blockchainNetwork: 'local',
            stdmigrate: options.stdmigrate || false
        };
        // TODO: uncomment when implement up enviroment with docker
        // if (!startOptions.useDocker) {
        //   startOptions.useDocker = (await this._params.prompt(
        //     this._params.getQuestion('useDocker')
        //   )).useDocker
        // }
        Utils.changeStartOptionsJSON(startOptions);
        try {
            (!startOptions.useDocker)
                ? await this.startLocalENV(startOptions)
                : await this.startDockerLocalENV(startOptions);
        }
        catch (error) {
            Utils.exitProgram(process.pid, error, 1);
        }
    }
    async stop() {
        try {
            if (!require(this._config.startOptions).useDocker) {
                await this._params.processManager.deletePM2Service('all');
            }
            else {
                await this._params.processManager.startChildProcess('docker-compose down', path_1.default.join(__dirname, '../'));
            }
            log.info(chalk_1.default.green('\nEnviroment stoped\n'));
        }
        catch (error) {
            Utils.exitProgram(process.pid, chalk_1.default.red(`\nEnviroment undefined or already stoped\n`), 1);
        }
    }
    async viewLogs(options) {
        let targetLog = 'bankroller';
        switch (true) {
            case options.testrpc:
                targetLog = 'testrpc';
                break;
            case options.bankroller:
                targetLog = 'bankroller';
                break;
            default:
                targetLog = (await this._params.prompt(this._params.getQuestion('targetLog'))).targetLog;
        }
        if (!require(this._config.startOptions).useDocker) {
            this._params.processManager.startChildProcess(`npm run logs:pm2:${targetLog}`, path_1.default.join(__dirname, '../'));
        }
        else {
            this._params.processManager.startChildProcess(`npm run logs:docker:${targetLog}`, path_1.default.join(__dirname, '../'));
        }
    }
    async startTestRPC(options) {
        let { host, port, nodb, background } = options;
        try {
            switch (true) {
                case !host:
                    host = (await this._params.prompt(this._params.getQuestion('inputTestRPCHost'))).testrpcHost;
                case !port:
                    port = (await this._params.prompt(this._params.getQuestion('inputTestRPCPort'))).testrpcPort;
                case !nodb:
                    nodb = !(await this._params.prompt(this._params.getQuestion('useTestRPCDB'))).nodb;
                case !background:
                    background = (await this._params.prompt(this._params.getQuestion('startInBackground'))).startInBackground;
            }
            const START_ENV = {
                'hostname': host,
                'port': port,
                'no_db': nodb || false
            };
            if (background) {
                await this._params.processManager.listenExitPM2service();
                const testrpcUp = await this._params.processManager.startPM2Service({
                    cwd: path_1.default.dirname(require.resolve('@daocasino/dc-protocol')),
                    name: 'dc-protocol',
                    env: START_ENV,
                    wait_ready: true,
                    listen_timeout: 3000,
                    exec_mode: 'fork',
                    script: require.resolve('@daocasino/dc-protocol/src/testrpc.server.js')
                });
                log.info(`\n
          \rtestrpc start in background with pm2 status: ${chalk_1.default.green(testrpcUp.status)}
          \rfor show logs ganache testrpc please run 
          \r${chalk_1.default.green('dc-cli logs --testrpc')} or ${chalk_1.default.green('pm2 logs dc-protocol')}
          \rfor stop process need run ${chalk_1.default.green('dc-cli stop')}\n
        `);
            }
            else {
                this._params.processManager.startChildProcess(`node ${require.resolve('@daocasino/dc-protocol/src/testrpc.server.js')}`, path_1.default.dirname(require.resolve('@daocasino/dc-protocol')), START_ENV);
            }
        }
        catch (error) {
            throw error;
        }
    }
    async startBankrollerWithNetwork(options) {
        const bankrollerStartScript = require.resolve('@daocasino/bankroller-node');
        let startInBackground = options.background;
        let blockchainNetwork = options.network;
        let bankrollerPrivatekey = options.privatekey;
        try {
            if (!blockchainNetwork) {
                blockchainNetwork = (await this._params.prompt(this._params.getQuestion('selectBlockchainNetwork'))).blockchainNetwork;
            }
            if (blockchainNetwork === 'local') {
                bankrollerPrivatekey = this._config.bankrollerLocalPrivateKey;
            }
            else if (!bankrollerPrivatekey) {
                bankrollerPrivatekey = (await this._params.prompt(this._params.getQuestion('inputPrivateKey'))).privateKeyToBankroller;
            }
            if (!startInBackground) {
                startInBackground = (await this._params.prompt(this._params.getQuestion('startInBackground'))).startInBackground;
            }
            const START_ENV = {
                'DC_NETWORK': blockchainNetwork,
                'DAPPS_FULL_PATH': path_1.default.join(path_1.default.dirname(bankrollerStartScript), '../data/dapps'),
                'ACCOUNT_PRIVATE_KEY': bankrollerPrivatekey
            };
            Utils.changeStartOptionsJSON({
                useDocker: !startInBackground,
                blockchainNetwork
            });
            if (startInBackground) {
                await this._params.processManager.listenExitPM2service();
                const bankrollerUp = (await this._params.processManager.startPM2Service({
                    cwd: path_1.default.dirname(bankrollerStartScript),
                    name: 'bankroller-node',
                    exec_mode: 'fork',
                    env: START_ENV,
                    wait_ready: true,
                    listen_timeout: 3000,
                    script: path_1.default.basename(bankrollerStartScript)
                }));
                log.info(`\n
          \rBankroller start in background with pm2 status: ${chalk_1.default.green(bankrollerUp.status)}
          \rfor show logs bankroller please run 
          \r${chalk_1.default.green('dc-cli logs --bankroller')} or ${chalk_1.default.green('pm2 logs bankroller-node')}
          \rfor stop process need run ${chalk_1.default.green('dc-cli stop')}\n
        `);
            }
            else {
                this._params.processManager.startChildProcess(`node ${bankrollerStartScript}`, path_1.default.join(__dirname, '../'), START_ENV);
            }
        }
        catch (error) {
            Utils.exitProgram(process.pid, error, 1);
        }
    }
    async startLocalENV(startOptions = require(this._config.startOptions)) {
        try {
            await this.startTestRPC({ host: '0.0.0.0', port: 8545, nodb: true, background: true });
            const migrateToLocalNetwork = await this.migrateContract({
                network: startOptions.blockchainNetwork,
                stdmigrate: startOptions.stdmigrate
            });
            if (migrateToLocalNetwork === 'success') {
                await this.startBankrollerWithNetwork({
                    background: true,
                    exit: false,
                    privatekey: this._config.bankrollerLocalPrivateKey,
                    network: startOptions.blockchainNetwork
                });
            }
        }
        catch (error) {
            await this.stop();
            Utils.exitProgram(process.pid, error.message, 1);
        }
    }
    async startDockerLocalENV(startOptions = require(this._config.startOptions)) {
        log.info('comming soon...');
        // TODO: Implement
    }
}
exports.default = DApp;
//# sourceMappingURL=DApp.js.map