"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const chalk_1 = __importDefault(require("chalk"));
const Utils = __importStar(require("./Utils"));
const dc_logging_1 = require("@daocasino/dc-logging");
const PingService_1 = require("@daocasino/bankroller-core/lib/dapps/PingService");
const dc_messaging_1 = require("@daocasino/dc-messaging");
const log = new dc_logging_1.Logger('Deployer');
class Deployer {
    constructor(params) {
        this._params = params;
    }
    async migrateContract(options) {
        let network = options.network;
        let mnemonic = null;
        let contractsPath = null;
        const USE_STD_CONTRACTS = options.stdmigrate;
        const DEFAULT_CONTRACTS_PATH = path_1.default.join(process.cwd(), './dapp/contracts');
        try {
            if (!network) {
                network = (await this._params.prompt(this._params.getQuestion('selectBlockchainNetwork'))).blockchainNetwork;
            }
            if (network !== 'local') {
                mnemonic = (await this._params.prompt(this._params.getQuestion('inputMnemonic'))).mnemonic;
            }
            if (USE_STD_CONTRACTS) {
                log.info(chalk_1.default.yellow('Use standart dc-protocol contract for migrate'));
            }
            else if (!fs_1.default.existsSync(DEFAULT_CONTRACTS_PATH)) {
                const GET_PATH = (await this._params.prompt(this._params.getQuestion('inputContractsPath'))).contractsPath;
                contractsPath = path_1.default.join(process.cwd(), GET_PATH);
                const PATH_TO_MIGRATE_CONTRACT = path_1.default.join(contractsPath, 'devtools/Migrations.sol');
                if (!fs_1.default.existsSync(PATH_TO_MIGRATE_CONTRACT)) {
                    log.info(chalk_1.default.yellow(`
            \rIn ${chalk_1.default.cyan(contractsPath)}
            \rnot ${chalk_1.default.green('Migrations.sol')} contract so dc-cli
            \rwill use standart contract for migrate
          `));
                }
            }
            const contractMigrate = await this._params.processManager.startChildProcess(`node CLI migrate --network ${network}`, path_1.default.join(path_1.default.dirname(require.resolve('@daocasino/dc-protocol')), '/bin'), {
                MNEMONIC: mnemonic,
                CONTRACTS_PATH: contractsPath
            });
            if (contractMigrate.status === 'success') {
                log.info(`>> Contracts deploy to ${network} network successed <<`);
                return contractMigrate.status;
            }
        }
        catch (error) {
            Utils.exitProgram(process.pid, chalk_1.default.red(error.message), 1);
        }
    }
    async uploadGameToBankroller(options) {
        let { address: targetBankrollerAddress, gamePath, platformid } = options;
        switch (true) {
            case !platformid:
                platformid = (await this._params.prompt(this._params.getQuestion('inputPlatformID'))).platformID;
            case !targetBankrollerAddress:
                targetBankrollerAddress = (await this._params.prompt(this._params.getQuestion('inputBankrollerAddress'))).bankrollerAddress;
            case !gamePath:
                gamePath = (await this._params.prompt(this._params.getQuestion('inputGamePath'))).gamePath;
        }
        const TARGET_GAME_PATH = path_1.default.join(process.cwd(), gamePath);
        const FILE_NAME_TEMPLATE = /dapp[\.\-_](manifest|logic)\.js/;
        if (!fs_1.default.existsSync(TARGET_GAME_PATH)) {
            throw new Error(chalk_1.default.red(`TARGET_GAME_PATH: ${chalk_1.default.cyan(TARGET_GAME_PATH)} not exists`));
        }
        const GAME_FILES = fs_1.default.readdirSync(TARGET_GAME_PATH)
            .filter(fileName => (FILE_NAME_TEMPLATE.test(fileName)) && fileName)
            .map(fileName => {
            return {
                fileName,
                fileData: fs_1.default.readFileSync(path_1.default.join(TARGET_GAME_PATH, fileName)).toString('base64')
            };
        });
        if (GAME_FILES.length < 2) {
            throw new Error(chalk_1.default.red(`Not logic game and manifest file in ${chalk_1.default.cyan(TARGET_GAME_PATH)}`));
        }
        try {
            const GAME_DIRECTORY_NAME = require(path_1.default.join(TARGET_GAME_PATH, 'dapp.manifest.js')).slug;
            await this._pingServiceConnect(platformid, async (data) => {
                if (data.ethAddress.toLowerCase() === targetBankrollerAddress.toLowerCase()) {
                    const UPLOAD_DATA = Object.assign({}, data, { gameFiles: GAME_FILES, targetGamePath: TARGET_GAME_PATH, gameDirectoryName: GAME_DIRECTORY_NAME });
                    this.uploadGame(UPLOAD_DATA);
                }
            });
            this._pingService.emit(PingService_1.PingService.EVENT_PING, null);
        }
        catch (error) {
            Utils.exitProgram(process.pid, chalk_1.default.red(`${error.message} please try upload again`), 1);
        }
    }
    async unloadGameInBankroller(options) {
        let { address: targetBankrollerAddress, gameName, platformid } = options;
        switch (true) {
            case !platformid:
                platformid = (await this._params.prompt(this._params.getQuestion('inputPlatformID'))).platformID;
            case !targetBankrollerAddress:
                targetBankrollerAddress = (await this._params.prompt(this._params.getQuestion('inputBankrollerAddress'))).bankrollerAddress;
            case !gameName:
                gameName = (await this._params.prompt(this._params.getQuestion('inputGameName'))).gamePath;
        }
        try {
            await this._pingServiceConnect(platformid, async (data) => {
                if (data.ethAddress.toLowerCase() === targetBankrollerAddress.toLowerCase()) {
                    const UNLOAD_PARAMS = Object.assign({}, data, { gameName });
                    await this.unloadGame(UNLOAD_PARAMS);
                }
            });
            this._pingService.emit(PingService_1.PingService.EVENT_PING, null);
        }
        catch (error) {
            Utils.exitProgram(process.pid, chalk_1.default.red(`${error.message} please try upload again`), 1);
        }
    }
    async deployGameToIPFS() {
        log.info('comming soon...');
    }
    async publishGame() {
        log.info('comming soon...');
    }
    async _pingServiceConnect(platformid, handler) {
        try {
            this._transportProviderFactory = new dc_messaging_1.TransportProviderFactory(dc_messaging_1.TransportType.IPFS);
            this._provider = await this._transportProviderFactory.create();
            this._pingService = await this._provider.getRemoteInterface(platformid);
            this._pingService.on(PingService_1.PingService.EVENT_PONG, handler);
            log.info(chalk_1.default.green('\nPing service connection estimate!\n'));
        }
        catch (error) {
            throw error;
        }
    }
    async uploadGame(data) {
        const { gameFiles, apiRoomAddress, gameDirectoryName, } = data;
        try {
            const bankrollerInstance = await this._provider.getRemoteInterface(apiRoomAddress);
            const uploadGame = await bankrollerInstance.uploadGame({
                name: gameDirectoryName,
                files: gameFiles,
                reload: true
            });
            if (uploadGame.status === 'ok') {
                log.info(chalk_1.default.yellow('\nUpload game success, destroy connection please wait...'));
                await this._provider.destroy();
            }
        }
        catch (error) {
            Utils.exitProgram(process.pid, chalk_1.default.red(`${error.message} please try upload again`), 1);
        }
    }
    async unloadGame(data) {
        const { gameName, apiRoomAddress } = data;
        try {
            const bankrollerInstance = await this._provider.getRemoteInterface(apiRoomAddress);
            const unloadGame = await bankrollerInstance.unloadGame(gameName);
            if (unloadGame.status === 'ok') {
                await this._provider.destroy();
                log.info(chalk_1.default.yellow('\nUnload game success, destroy connection please wait...'));
            }
        }
        catch (error) {
            Utils.exitProgram(process.pid, chalk_1.default.red(`${error.message} please try upload again`), 1);
        }
    }
}
exports.default = Deployer;
//# sourceMappingURL=Deployer.js.map