"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const pm2_1 = __importDefault(require("pm2"));
const chalk_1 = __importDefault(require("chalk"));
const Utils = __importStar(require("./Utils"));
const child_process_1 = require("child_process");
const dc_logging_1 = require("@daocasino/dc-logging");
const bluebird_1 = require("bluebird");
const log = new dc_logging_1.Logger('ProcessManager:');
class ProcessManager {
    constructor() {
        this.PromisePm2Api = bluebird_1.Promise.promisifyAll(pm2_1.default);
        this.logs = { error: [], info: [] };
    }
    async startChildProcess(command, target, userEnv = {}) {
        return new bluebird_1.Promise((resolve, reject) => {
            const asignEnv = Object.assign({}, process.env, userEnv);
            const startChildProcess = child_process_1.exec(command, {
                cwd: target,
                env: asignEnv
            });
            const printOut = data => log.info(data);
            startChildProcess.stdout.on('data', printOut);
            startChildProcess.stderr.on('data', printOut);
            startChildProcess.on('error', error => reject(error));
            startChildProcess.on('exit', code => {
                startChildProcess.stdout.off('data', printOut);
                startChildProcess.stderr.off('data', printOut);
                (code !== 0)
                    ? reject(new Error(`child procces ${command} exit with code ${code}`))
                    : resolve({ status: 'success' });
            });
        });
    }
    async listenExitPM2service() {
        try {
            const pm2EventBus = await this.PromisePm2Api.launchBusAsync();
            pm2EventBus.on('log:err', errorData => this.logs.error.push(errorData.data));
            pm2EventBus.on('process:event', this.exitHandler.bind(this));
        }
        catch (error) {
            throw error;
        }
    }
    async tornOffExitListenPM2Service() {
        try {
            const pm2EventBus = await this.PromisePm2Api.launchBusAsync();
            pm2EventBus.off('log:err', errorData => this.logs.error.push(errorData.data));
            pm2EventBus.off('process:event', this.exitHandler.bind(this));
        }
        catch (error) {
            throw error;
        }
    }
    async startPM2Service(serviceConfig) {
        try {
            await this.PromisePm2Api.connectAsync();
            const pm2Process = await this.PromisePm2Api.startAsync(serviceConfig);
            if (pm2Process.length > 0) {
                await this.PromisePm2Api.disconnectAsync();
                return pm2Process[0].pm2_env;
            }
        }
        catch (error) {
            throw error;
        }
    }
    async deletePM2Service(name) {
        try {
            await this.PromisePm2Api.deleteAsync(name);
            await this.PromisePm2Api.disconnectAsync();
        }
        catch (error) {
            throw error;
        }
    }
    async exitHandler(errorData) {
        try {
            if (errorData.event === 'exit') {
                const { process: invalidProccess } = errorData;
                const errorLogParse = this.logs.error.join('\n');
                const errorMessage = chalk_1.default.yellow(`
          \rprocess with name ${chalk_1.default.cyan(invalidProccess.name)}
          \rclosed with error error message:
          \r${chalk_1.default.red(errorLogParse)}
        `);
                await this.deletePM2Service('all');
                await this.tornOffExitListenPM2Service();
                Utils.exitProgram(process.pid, errorMessage, 1);
            }
        }
        catch (error) {
            throw error;
        }
    }
}
exports.default = ProcessManager;
//# sourceMappingURL=ProcessManager.js.map