"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const chalk_1 = __importDefault(require("chalk"));
const config_1 = __importDefault(require("./config/config"));
const ncp_1 = require("ncp");
const dc_logging_1 = require("@daocasino/dc-logging");
const node_machine_id_1 = require("node-machine-id");
const log = new dc_logging_1.Logger('Utils');
exports.sudo = () => (typeof process.env.SUDO_UID !== 'undefined') ? 'sudo -E' : '';
exports.checkENV = () => !(!fs_1.default.existsSync(config_1.default.projectsENV));
exports.UUIDGenerate = () => node_machine_id_1.machineIdSync(true);
function changeStartOptionsJSON(options) {
    if (!fs_1.default.existsSync(config_1.default.startOptions)) {
        fs_1.default.writeFileSync(config_1.default.startOptions, JSON.stringify({}));
    }
    const startConfigJSON = require(config_1.default.startOptions);
    if (!config_1.default.networksName.includes(options.blockchainNetwork)) {
        throw new Error(chalk_1.default.red(`Network with name ${chalk_1.default.cyan(options.blockchainNetwork)} does not exist`));
    }
    if (startConfigJSON.useDocker !== options.useDocker ||
        startConfigJSON.blockchainNetwork !== options.blockchainNetwork) {
        const openFile = fs_1.default.openSync(config_1.default.startOptions, 'w');
        fs_1.default.writeSync(openFile, JSON.stringify(options, null, ' '), 0, 'utf-8');
        fs_1.default.closeSync(openFile);
        return options;
    }
    return startConfigJSON;
}
exports.changeStartOptionsJSON = changeStartOptionsJSON;
async function checkLatestVersion() {
    return null;
    // try {
    //   const checkVersion = await npmCheck(require(config.packageJSON))
    //   if (checkVersion !== null) {
    //     const latestVersion = checkVersion.latest
    //     const targetVersion = require(config.packageJSON).version
    //     if (targetVersion < latestVersion) {
    //       log.info(`
    //         \r${chalk.bgRgb(255, 194, 102).gray('  UPDATE AVALABLE  ')}
    //         \rPlease use ${chalk.green('npm i -g dc-cli@latest')},
    //         \rto update for lasst version dc-cli
    //         \rLast version: ${chalk.green(latestVersion)}
    //         \rYour version: ${chalk.red(targetVersion)}
    //       `)
    //     }
    //     return { latestVersion, targetVersion }
    //   } else {
    //     return null
    //   }
    // } catch (error) {
    //   throw error
    // }
}
exports.checkLatestVersion = checkLatestVersion;
function exitProgram(pid, error, exitCode = 0) {
    if (error) {
        log.error(error);
    }
    process.exitCode = (exitCode !== null) ? exitCode : 1;
    process.kill(pid, 'SIGTERM');
}
exports.exitProgram = exitProgram;
function addExitListener(callback) {
    const signals = ['SIGINT', 'SIGKILL'];
    signals.forEach(signal => {
        process.on(signal, () => {
            if (callback)
                callback();
            exitProgram(process.ppid, false, 0);
        });
    });
}
exports.addExitListener = addExitListener;
function recursiveCopyDirectory(targetInputPath, targetOutputPath) {
    return new Promise((resolve, reject) => {
        ncp_1.ncp(targetInputPath, targetOutputPath, error => {
            if (error)
                reject(new Error(error[0].message));
            resolve();
        });
    });
}
exports.recursiveCopyDirectory = recursiveCopyDirectory;
//# sourceMappingURL=Utils.js.map