"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const Utils = __importStar(require("../Utils"));
const dc_logging_1 = require("@daocasino/dc-logging");
const chai_1 = require("chai");
const log = new dc_logging_1.Logger('Test:');
describe('Utils module test', () => {
    const testDappsPath = path_1.default.join(__dirname, './testData/recursiveCopyDirectory/recursiveTarget');
    before(() => {
        if (!fs_1.default.existsSync(testDappsPath)) {
            fs_1.default.mkdirSync(testDappsPath);
        }
    });
    afterEach(() => {
        delete process.env.SUDO_UID;
    });
    it('changeStartOptionsJSON call', () => {
        // Arrange
        const newStartOptions = { useDocker: true, blockchainNetwork: 'local', stdmigrate: false };
        // Act
        const changeOptions = Utils.changeStartOptionsJSON(newStartOptions);
        // Assert
        chai_1.expect(changeOptions.useDocker).to.be.equal(newStartOptions.useDocker);
        chai_1.expect(changeOptions.blockchainNetwork).to.be.equal(newStartOptions.blockchainNetwork);
        chai_1.expect(changeOptions.stdmigrate).to.be.equal(newStartOptions.stdmigrate);
    });
    it('start with sudo', () => {
        // Arrange
        process.env.SUDO_UID = '222';
        // Act
        const checkSudo = Utils.sudo();
        // Assert
        chai_1.expect(typeof checkSudo).to.be.a('string');
        chai_1.expect(checkSudo).to.be.eq('sudo -E');
    });
    it('start without sudo', () => {
        // Act
        const checkSudo = Utils.sudo();
        // Assert
        chai_1.expect(typeof checkSudo).to.be.a('string');
        chai_1.expect(checkSudo).to.be.eq('');
    });
    it('UUIDGenerate call', () => {
        // Act
        const uuid = Utils.UUIDGenerate();
        // Assert
        chai_1.expect(typeof uuid).to.be.a('string');
        // expect(uuid.length).to.be.eq(36)
    });
    it('check dc enviroment', () => {
        // Act
        const checkEnv = Utils.checkENV();
        // Assert
        chai_1.expect(checkEnv).to.be.eq(false);
    });
    it('recursiveCopyDirectory call', async () => {
        // Arrange
        const targetInputPath = path_1.default.join(__dirname, './testData/recursiveCopyDirectory/recursiveCopy');
        const targetOutputPath = path_1.default.join(__dirname, './testData/recursiveCopyDirectory/recursiveTarget');
        // Act
        await Utils.recursiveCopyDirectory(targetInputPath, targetOutputPath);
        const checkExistOutDir = fs_1.default.existsSync(targetOutputPath);
        const checkFilesInOutDir = fs_1.default.readdirSync(targetOutputPath);
        // Assert
        chai_1.expect(checkExistOutDir).to.be.eq(true);
        chai_1.expect(checkFilesInOutDir.length).to.be.least(0);
    });
    it('recursiveCopyDirectory error params', async () => {
        const targetInputPath = path_1.default.join(__dirname, './testData/recursiveCopyDirectory/recursiveCopy');
        const targetOutputPath = '/.&&&222';
        try {
            await Utils.recursiveCopyDirectory(targetInputPath, targetOutputPath);
        }
        catch (error) {
            chai_1.expect(error).to.instanceOf(Error);
        }
    });
});
//# sourceMappingURL=utils.test.js.map