"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const config_1 = __importDefault(require("../config/config"));
const commander_1 = __importDefault(require("commander"));
const index_1 = __importDefault(require("../index"));
const questions_1 = __importDefault(require("../config/questions"));
const Utils = __importStar(require("../Utils"));
const dc_logging_1 = require("@daocasino/dc-logging");
const commands = {};
const log = new dc_logging_1.Logger('CLI');
const CLI = new index_1.default({ config: config_1.default, getQuestion: questions_1.default });
config_1.default.commands.forEach(command => { commands[command.name] = command; });
function run() {
    const programArgs = process.argv.slice(2);
    let targetCommand = null;
    for (const command in commands) {
        if (commands[command].name === programArgs[0]) {
            targetCommand = commands[command];
        }
    }
    /**
     * If not enviroment and command needed env
     * then output error log and exit
     */
    if ((!programArgs.includes('-f') && !programArgs.includes('--force')) &&
        (!Utils.checkENV() && targetCommand && targetCommand.env)) {
        const error = new Error(chalk_1.default.red('\nError cannot created project please run dc-cli create and try again\n'));
        Utils.exitProgram(process.pid, error, 0);
    }
    /** Parse command line arguments */
    commander_1.default.parse(process.argv);
    commander_1.default.cli = true;
    /** If arguments not exist then view main menu cli */
    if (commander_1.default.args.length === 0) {
        CLI.viewMenu();
    }
}
/**
 * Listen all commands
 * if argument command not exists in cli
 * commands then view main menu cli
 */
commander_1.default.on('command:*', () => CLI.viewMenu());
/* tslint:disable:no-string-literal */
/* tslint:disable:no-var-requires */
commander_1.default
    .version(`CLI version: ${chalk_1.default.red(require(config_1.default.packageJSON).version)}`)
    .usage('<command> [options]')
    .description(chalk_1.default.green('CLI for light development with DC ENV'));
commander_1.default
    .command('list')
    .description(`${chalk_1.default.green(commands['list'].description.trim())} `)
    .action(() => CLI.viewTemplateList());
commander_1.default
    .command('create [template] [directory]')
    .description(`${chalk_1.default.green(commands['create'].description.trim())} `)
    .usage(`${chalk_1.default.red('<template-name> <project-name>')}`)
    .option('-y, --yarn', 'Use yarn package manager for install')
    .action((template, directory, command) => CLI.createProject(template, directory, command))
    .on('--help', () => {
    log.info(`
      Template run:

        dc-cli create ${chalk_1.default.cyan('<template-name> <project-name> [options]')}
      
      Example run:

        dc-cli create ${chalk_1.default.green('webpack my-project')}
      ${chalk_1.default.yellow(`
        If arguments are not passed then cli will
        ask, leading questions and set needed arguments 
      `)}
    `);
});
commander_1.default
    .command('start')
    .description(`${chalk_1.default.green(commands['start'].description.trim())} `)
    .usage(`${chalk_1.default.red('[options]')}`)
    // .option('-d, --docker', 'Start env in docker containers')
    .option('-s, --stdmigrate', 'Start protocol with standart dc-protocol contracts')
    .action(command => CLI.DApp.start(command));
commander_1.default
    .command('testrpcup')
    .description(`${chalk_1.default.green(commands['testrpcup'].description.trim())} `)
    .usage(`${chalk_1.default.red('[options]')}`)
    .option('-h, --host <host>', 'Use your custom host for ganache testrpc, default 0.0.0.0')
    .option('-p, --port <port>', 'Use your custom port for ganache testrpc, default 8545')
    .option('-n, --nodb', `Don't use data base in ganache testrpc`)
    .option('-b, --background', 'Start process in')
    .action(command => CLI.DApp.startTestRPC(command));
commander_1.default
    .command('bankrollup')
    .description(`${chalk_1.default.green(commands['bankrollup'].description.trim())} `)
    .usage(`${chalk_1.default.red('[options]')}`)
    .option('-b, --background', 'Start bankroller in background (pm2)')
    .option('-p, --privatekey <privatekey>', 'Input private key for start bankroller in needed network')
    .option('-n, --network <network>', 'Start bankroller in target blockchain network')
    .action(command => CLI.DApp.startBankrollerWithNetwork(command))
    .on('--help', () => {
    log.info(`
      Template run:

        dc-cli bankup ${chalk_1.default.cyan('[options]')}

      Example run:

        dc-cli bankup --background --network ${chalk_1.default.green('ropsten')} --privatekey ${chalk_1.default.green('0x1882c2a6d0df1210d643f82f69d0bdfa0e2e1eaa963384826a4f24d5b5529e10')}
      ${chalk_1.default.yellow(`
        If arguments are not passed then cli will
        ask, leading questions and set needed arguments 
      `)}
    `);
});
commander_1.default
    .command('stop')
    .description(`${chalk_1.default.green(commands['stop'].description.trim())} `)
    .usage(`${chalk_1.default.red('[options]')}`)
    .action(() => CLI.DApp.stop());
commander_1.default
    .command('logs')
    .description(`${chalk_1.default.green(commands['logs'].description.trim())} `)
    .usage(`${chalk_1.default.red('[options]')}`)
    .option('-b, --bankroller', 'View bankroller logs')
    .option('-t, --testrpc', 'View testrpc logs')
    // .option('-d, --docker', 'Start docker logs')
    .action(command => CLI.DApp.viewLogs(command));
commander_1.default
    .command('migrate')
    .description(`${chalk_1.default.green(commands['migrate'].description.trim())} `)
    .usage(`${chalk_1.default.red('[options]')}`)
    .option('-n, --network <network>', 'Blockchain network for migrate')
    .option('-s, --stdmigrate', 'Migrate standart contract in dc-protocol')
    .action(command => CLI.DApp.migrateContract(command));
// program
//   .command('upload-game')
//   .description(`${chalk.green(commands['upload-game'].description.trim())} `)
//   .usage(`${chalk.red('[options]')}`)
//   .option('-p, --platformid <platformId>')
//   .option('-a, --address <bankrollerAddress>', 'Bankroller address')
//   .option('-g, --game-path <gamePath>', 'Path to upload dapp.logic.js and dapp.manifest.js')
//   .action(command => CLI.DApp.uploadGameToBankroller(command))
//   .on('--help', () => {
//     log.info(`
//       Template run:
//         dc-cli upload ${chalk.cyan('[options]')}
//       Example run:
//         dc-cli upload --platformid ${chalk.green('DC_Platform')} --address ${chalk.green('0xf3b7416161E69B4fbF8b7E61a9326F4251ca0a5D')} --game-path ${chalk.green('./dapp')}
//       ${chalk.yellow(`
//         If arguments are not passed then cli will
//         ask, leading questions and set needed arguments 
//       `)}
//     `)
//   })
// program
//   .command('unload-game')
//   .description(`${chalk.green(commands['unload-game'].description.trim())} `)
//   .usage(`${chalk.red('[options]')}`)
//   .option('-p, --platformid <platformId>')
//   .option('-a, --address <bankrollerAddress>', 'Bankroller address')
//   .option('-n, --game-name <gameName>', 'Path to upload dapp.logic.js and dapp.manifest.js')
//   .action(command => CLI.DApp.unloadGameInBankroller(command))
//   .on('--help', () => {
//     log.info(`
//       Template run:
//         dc-cli upload ${chalk.cyan('[options]')}
//       Example run:
//         dc-cli upload --platformid ${chalk.green('DC_Platform')} --address ${chalk.green('0xf3b7416161E69B4fbF8b7E61a9326F4251ca0a5D')} --game-name ${chalk.green('MyDappGame')}
//       ${chalk.yellow(`
//         If arguments are not passed then cli will
//         ask, leading questions and set needed arguments 
//       `)}
//     `)
//   })
// program
//   .command('deploy')
//   .description(`${chalk.green(commands['deploy'].description.trim())} `)
//   .usage(`${chalk.red('[options]')}`)
//   .option('-f, --force', 'Force run command not depend enviroment')
//   .action(() => CLI.DApp.deployGameToIPFS())
// program
//   .command('publish')
//   .description(`${chalk.green(commands['publish'].description.trim())} `)
//   .usage(`${chalk.red('[options]')}`)
//   .option('-f, --force', 'Force run command not depend enviroment')
//   .action(() => CLI.DApp.publishGame())
run();
//# sourceMappingURL=index.js.map