"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const chalk_1 = __importDefault(require("chalk"));
const config_1 = __importDefault(require("./config"));
const Utils = __importStar(require("../Utils"));
function getQuestion(name) {
    const questions = {
        viewMenu: {
            name: 'command',
            message: `You did not enter a command or enter a nonexistent, What do you want to do?: `,
            type: 'list',
            pageSize: 15,
            choices: config_1.default.commands
                .filter(command => !((Utils.checkENV() && (command.name === 'list' || command.name === 'create'))))
                .map(command => {
                if (!Utils.checkENV() && command.env) {
                    command.name = `${chalk_1.default.rgb(128, 128, 128)(command.name)}`;
                }
                return `${command.name} ${chalk_1.default.green(command.description)}`;
            })
        },
        templateSelect: {
            type: 'list',
            name: 'template',
            message: 'Select the standart template?: ',
            choices: config_1.default.templates.map(template => template.name)
        },
        directoryInput: {
            type: 'input',
            name: 'directory',
            message: 'Input directory name to project?: '
        },
        useYarn: {
            type: 'confirm',
            name: 'useYarn',
            message: 'Use yarn package manager',
            default: true
        },
        useDocker: {
            type: 'confirm',
            name: 'useDocker',
            message: 'Use docker containers for up enviroment',
            default: false
        },
        targetLog: {
            type: 'list',
            name: 'targetLog',
            message: 'Please select target to start logs',
            choices: ['testrpc', 'bankroller']
        },
        selectBlockchainNetwork: {
            type: 'list',
            name: 'blockchainNetwork',
            message: 'Please select network to start',
            choices: ['local', 'ropsten', 'rinkeby']
        },
        inputPrivateKey: {
            type: 'input',
            name: 'privateKeyToBankroller',
            message: 'Please input private key with eth and bet balance for bankroller'
        },
        inputMnemonic: {
            type: 'input',
            name: 'mnemonic',
            message: 'Input mnemonic for deploy contract to the test network'
        },
        startInBackground: {
            type: 'confirm',
            name: 'startInBackground',
            message: 'Start process in background',
            default: false
        },
        inputPlatformID: {
            type: 'input',
            name: 'platformID',
            message: 'Input platform id for create connect with bankroller'
        },
        inputGamePath: {
            type: 'input',
            name: 'gamePath',
            message: 'Input path to the game logic and dapp.manifest files'
        },
        inputBankrollerAddress: {
            type: 'input',
            name: 'bankrollerAddress',
            message: 'Input bankroller address at upload game'
        },
        inputGameName: {
            type: 'input',
            name: 'gamename',
            message: 'Input name for game'
        },
        inputContractsPath: {
            type: 'input',
            name: 'contractsPath',
            message: `not contracts in ${path_1.default.join(process.cwd(), './dapp/contracts')} directory, please input correct path to protocol contracts`
        },
        inputTestRPCHost: {
            type: 'input',
            name: 'testrpcHost',
            message: 'How use host for ganache?'
        },
        inputTestRPCPort: {
            type: 'input',
            name: 'testrpcPort',
            message: 'How use port for ganache?'
        },
        useTestRPCDB: {
            type: 'confirm',
            name: 'nodb',
            message: 'Use DB in ganache?',
            default: true
        }
    };
    return questions[name];
}
exports.default = getQuestion;
//# sourceMappingURL=questions.js.map