"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const DApp_1 = __importDefault(require("./DApp"));
const chalk_1 = __importDefault(require("chalk"));
const inquirer_1 = __importDefault(require("inquirer"));
const download_1 = __importDefault(require("download"));
const ProcessManager_1 = __importDefault(require("./ProcessManager"));
const Utils = __importStar(require("./Utils"));
const child_process_1 = require("child_process");
const dc_logging_1 = require("@daocasino/dc-logging");
const log = new dc_logging_1.Logger('CLIInstance:');
class CLIInstance {
    constructor(params) {
        this._params = params;
        this._config = this._params.config;
        this._prompt = inquirer_1.default.createPromptModule();
        this._nodeStart = `node ${path_1.default.join(__dirname, '../bin/CLI')}`;
        this._getQuestion = this._params.getQuestion;
        this._processManager = new ProcessManager_1.default;
        if (!fs_1.default.existsSync(this._config.startOptions)) {
            fs_1.default.writeFileSync(this._config.startOptions, JSON.stringify({}));
        }
        this.DApp = new DApp_1.default({
            prompt: this._prompt,
            config: this._config,
            nodeStart: this._nodeStart,
            getQuestion: this._getQuestion,
            processManager: this._processManager
        });
    }
    async viewMenu() {
        /**
         * Generate menu with commands
         * if env not equal dc-gamesample then
         * all command besides create and list not used
         */
        const commandSelected = (await this._prompt(this._getQuestion('viewMenu'))).command.split(' ')[0];
        /** Delete color string and start bin file with command */
        const commandWithoutColor = commandSelected.replace(this._config.ASCIIColor, '');
        child_process_1.spawn(`${Utils.sudo()} ${this._nodeStart} ${commandWithoutColor}`, [], {
            cwd: process.cwd(),
            shell: true,
            stdio: 'inherit'
        });
    }
    async viewTemplateList() {
        try {
            await Utils.checkLatestVersion();
            log.info(chalk_1.default.yellow('Templates list:'));
            this._config.templates.forEach(template => {
                log.info(`
          \r${chalk_1.default.yellow('★')} ${chalk_1.default.blue(template.name)} - ${template.descript} ${chalk_1.default.red(template.doc)}
        `);
            });
        }
        catch (error) {
            throw error;
        }
    }
    async createProject(template, directory, options) {
        await Utils.checkLatestVersion();
        let useYarn = options.yarn;
        switch (true) {
            case typeof template === 'undefined':
                template = (await this._prompt(this._getQuestion('templateSelect'))).template;
            case typeof directory === 'undefined':
                directory = (await this._prompt(this._getQuestion('directoryInput'))).directory;
            case !useYarn:
                useYarn = (await this._prompt(this._getQuestion('useYarn'))).useYarn;
        }
        try {
            const targetDirectory = path_1.default.join(process.cwd(), `${directory}`);
            const packageManager = (useYarn) ? 'yarn' : 'npm';
            if (!fs_1.default.existsSync(targetDirectory)) {
                fs_1.default.mkdirSync(targetDirectory);
            }
            await this.downloadProject(template, targetDirectory);
            await this.installProject(packageManager, targetDirectory);
        }
        catch (error) {
            Utils.exitProgram(process.pid, error);
        }
    }
    async downloadProject(templateName, targetDirectory) {
        const readTargetDirectory = fs_1.default.readdirSync(targetDirectory);
        if (readTargetDirectory.length !== 0) {
            throw new Error('Directory is not empty');
        }
        const downloadData = await download_1.default(`https://github.com/${templateName}/archive/development.zip`, targetDirectory, {
            extract: true,
            strip: 1,
            mode: '666',
            headers: { accept: 'application/zip' }
        });
        if (downloadData) {
            log.info('Download sample success');
            return true;
        }
    }
    async installProject(packageManager, targetDirectory) {
        const generateCommand = `${packageManager} install`;
        const installProject = await this._processManager.startChildProcess(generateCommand, targetDirectory);
        if (installProject.status === 'success') {
            log.info('Install sample success');
            return true;
        }
    }
}
exports.default = CLIInstance;
//# sourceMappingURL=index.js.map